@@ -56,10 +56,12 @@ class AdminMixin:
 
     def changelist_view(self, request, extra_context=None):
         extra_context = extra_context or {}
-        extra_context["ddb_url"] = reverse(
+        url = reverse(
             "data_browser:query_html",
             args=[f"{self.model._meta.app_label}.{self.model.__name__}", ""],
         )
+        args = getattr(self, "ddb_default_filters", "")
+        extra_context["ddb_url"] = f"{url}?{args}"
         return super().changelist_view(request, extra_context)
 
 
