@@ -52,12 +52,12 @@ _TYPE_AGGREGATES = defaultdict(
             ("sum", NumberType),
             ("variance", NumberType),
         ],
-        DateTimeType: [  # average, min and max might be nice here but sqlite
-            ("count", NumberType)
-        ],
-        DateType: [  # average, min and max might be nice here but sqlite
-            ("count", NumberType)
+        DateTimeType: [
+            ("count", NumberType),
+            ("max", DateTimeType),
+            ("min", DateTimeType),
         ],
+        DateType: [("count", NumberType), ("max", DateType), ("min", DateType)],
         DurationType: [
             ("count", NumberType),
             ("average", DurationType),
@@ -254,6 +254,10 @@ class OrmModel:
     def root(self):
         return bool(self.admin)
 
+    @property
+    def default_filters(self):
+        return getattr(self.admin, "ddb_default_filters", "")
+
 
 @dataclass
 class OrmBaseField:
